create or replace package SVCO.vcontrol authid current_user is
  /*
  * "Schema Version Control for Oracle" (SVCO)
  *      http://www.sumsoftsolutions.com
  * PLEASE READ LICENSE AGREEMENT CAREFULLY BEFORE USING THIS SOFTWARE
  *
  * PURPOSE
  * This package is the user interface to Schema Version Control for Oracle functionality.
  *
  * SECURITY
  * This package is granted (EXECUTE rights) to SVCO_REP_OPERATOR and SVCO_REP_ADMIN roles.
  */

  --
  -- DESCRIPTION
  -- This function return current SVCO version.
  --
  -- PARAMETERS
  -- none
  --
  -- EXCEPTIONS
  -- exceptions_.exc_unhandled
  --
  -- TRANSACTION
  -- No.
  --
  function Get_SVCO_Version return varchar2;

  --
  -- DESCRIPTION
  -- This procedure saves purchased LICENSE KEY for SVCO product.
  --
  -- PARAMETERS
  -- Key - a purchased LICENSE KEY
  --
  -- EXCEPTIONS
  -- exceptions_.en_no_rights
  -- exceptions_.exc_unhandled
  --
  -- TRANSACTION
  -- This procedure performs a transaction.
  --
  procedure Save_License_Key(Key in char);

  --
  -- DESCRIPTION
  -- This function return 1 if SVCO is started or 0 - if not.
  --
  -- PARAMETERS
  -- none
  --
  -- EXCEPTIONS
  -- exceptions_.exc_unhandled
  --
  -- TRANSACTION
  -- No.
  --
  function SVCO_Started_To_Number return number;

  --
  -- DESCRIPTION
  -- This function return TRUE if SVCO is started or FALSE - if not.
  --
  -- PARAMETERS
  -- none
  --
  -- EXCEPTIONS
  -- exceptions_.exc_unhandled
  --
  -- TRANSACTION
  -- No.
  --
  function SVCO_Started return boolean;

  --
  -- DESCRIPTION
  -- This function return 1 if SVCO is enabled or 0 - if not.
  --
  -- PARAMETERS
  -- none
  --
  -- EXCEPTIONS
  -- exceptions_.exc_unhandled
  --
  -- TRANSACTION
  -- No.
  --
  function SVCO_Enabled_To_Number return number;

  --
  -- DESCRIPTION
  -- This function return TRUE if SVCO is enabled or FALSE - if not.
  --
  -- PARAMETERS
  -- none
  --
  -- EXCEPTIONS
  -- exceptions_.exc_unhandled
  --
  -- TRANSACTION
  -- No.
  --
  function SVCO_Enabled return boolean;

  --
  -- DESCRIPTION
  -- This procedure tries to enable SVCO.
  --
  -- PARAMETERS
  -- none
  --
  -- EXCEPTIONS
  -- exceptions_.en_no_rights
  -- exceptions_.en_no_data_found
  -- exceptions_.exc_unhandled
  --
  -- TRANSACTION
  -- No.
  --
  procedure Enable_Version_Control;

  --
  -- DESCRIPTION
  -- This procedure tries to disable SVCO.
  --
  -- PARAMETERS
  -- none
  --
  -- EXCEPTIONS
  -- exceptions_.en_no_rights
  -- exceptions_.en_no_data_found
  -- exceptions_.exc_unhandled
  --
  -- TRANSACTION
  -- No.
  --
  procedure Disable_Version_Control;

  --
  -- DESCRIPTION
  -- This function return 1 if role SVCO_REP_ADMIN is granted to session user or 0 - if not.
  --
  -- PARAMETERS
  -- none
  --
  -- EXCEPTIONS
  -- none
  --
  -- TRANSACTION
  -- No.
  --none
  function Has_Admin_Role return number;

  --
  -- DESCRIPTION
  -- This procedure tries to create new objects versions for given Schema_Name.
  --
  -- PARAMETERS
  -- Schema_Name - Schema name (user name) for which you create a new revision,
  --               if not given - perform operation for all known schemas in repository.
  --               Case insensitive.
  --
  -- EXCEPTIONS
  -- exceptions_.exc_no_rights
  -- exceptions_.exc_unhandled
  --
  -- TRANSACTION
  -- This procedure performs a transaction.
  --
  procedure Repository_Sync(Schema_Name in varchar2);

  --
  -- DESCRIPTION
  -- This procedure returns a DDL script for the given object version.
  --
  -- PARAMETERS
  -- Schema_Name - Schema name (user name). Case insensitive.
  --
  -- Object_Name - Object name. Case insensitive.
  --
  -- Object_Type - Object type. Case insensitive.
  --
  -- DDL - DDL script.
  -- 
  -- Version_ID - Object version number, if not given - last version.
  --
  -- New_Schema_Name - To be given when all objects are prefixed
  --                   with this schema name instead of original. Case insensitive.
  --
  -- With_Header - 'YES' indicate that DDL script includes SVCO header.
  --  
  -- EXCEPTIONS
  -- exceptions_.exc_no_data_found
  -- exceptions_.exc_too_many_rows
  -- exceptions_.en_no_rights
  -- exceptions_.exc_req_param
  -- exceptions_.exc_unhandled
  --
  -- TRANSACTION
  -- No.
  --
  procedure Get_Object_DDL(Schema_Name     in varchar2
                          ,Object_Name     in varchar2
                          ,Object_Type     in varchar2
                          ,DDL             out clob
                          ,Version_ID      in number default null
                          ,New_Schema_Name in varchar2 default null
                          ,With_Header     in varchar2 default 'YES');

  --
  -- DESCRIPTION
  -- This procedure returns a DDL script for the given dropped object version.
  --
  -- PARAMETERS
  -- Dropped_Object_ID - Dropped Object ID.
  --
  -- DDL - DDL script.
  -- 
  -- Version_ID - Object version number, if not given - last version.
  --
  -- New_Schema_Name - To be given when all objects are prefixed
  --                   with this schema name instead of original. Case insensitive.
  --
  -- With_Header - 'YES' indicate that DDL script includes SVCO header.
  --  
  -- EXCEPTIONS
  -- exceptions_.exc_no_data_found
  -- exceptions_.exc_too_many_rows
  -- exceptions_.en_no_rights
  -- exceptions_.exc_req_param
  -- exceptions_.exc_unhandled
  --
  -- TRANSACTION
  -- No.
  --
  procedure Get_Dropped_Object_DDL(Dropped_Object_ID in number
                                  ,DDL               out clob
                                  ,Version_ID        in number default null
                                  ,New_Schema_Name   in varchar2 default null
                                  ,With_Header       in varchar2 default 'YES');

  --
  -- DESCRIPTION
  -- This procedure delete the object version from repository.
  --
  -- PARAMETERS
  -- Schema_Name - Schema name (user name). Case insensitive.
  --
  -- Object_Name - Object name. Case insensitive.
  --
  -- Object_Type - Object type. Case insensitive.
  --
  -- Version_ID - Object version number.
  --
  -- EXCEPTIONS
  -- exceptions_.exc_no_data_found
  -- exceptions_.en_no_rights
  -- exceptions_.exc_unhandled
  --
  -- TRANSACTION
  -- This procedure performs a transaction.
  --
  procedure Delete_Object_Version(Schema_Name in varchar2
                                 ,Object_Name in varchar2
                                 ,Object_Type in varchar2
                                 ,Version_ID  in number);

  --
  -- DESCRIPTION
  -- This procedure delete the dropped object version from repository.
  --
  -- PARAMETERS
  -- Dropped_Object_ID - Dropped Object ID.
  --
  -- Version_ID - Object version number.
  --
  -- EXCEPTIONS
  -- exceptions_.exc_no_data_found
  -- exceptions_.en_no_rights
  -- exceptions_.exc_unhandled
  --
  -- TRANSACTION
  -- This procedure performs a transaction.
  --
  procedure Delete_Dropped_Object_Version(Dropped_Object_ID in number
                                         ,Version_ID        in number);

end vcontrol;
/
